import { z } from 'zod';
import { BackgroundType } from './enums';
declare const avatarPropsSchema: z.ZodObject<{
    isEnabled: z.ZodBoolean;
    url: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    isEnabled: boolean;
    url?: string | undefined;
}, {
    isEnabled: boolean;
    url?: string | undefined;
}>;
declare const containerColorsSchema: z.ZodObject<{
    backgroundColor: z.ZodString;
    color: z.ZodString;
}, "strip", z.ZodTypeAny, {
    color: string;
    backgroundColor: string;
}, {
    color: string;
    backgroundColor: string;
}>;
declare const inputColorsSchema: z.ZodObject<z.objectUtil.extendShape<{
    backgroundColor: z.ZodString;
    color: z.ZodString;
}, {
    placeholderColor: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    color: string;
    backgroundColor: string;
    placeholderColor: string;
}, {
    color: string;
    backgroundColor: string;
    placeholderColor: string;
}>;
export declare const chatThemeSchema: z.ZodObject<{
    hostAvatar: z.ZodOptional<z.ZodObject<{
        isEnabled: z.ZodBoolean;
        url: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        isEnabled: boolean;
        url?: string | undefined;
    }, {
        isEnabled: boolean;
        url?: string | undefined;
    }>>;
    guestAvatar: z.ZodOptional<z.ZodObject<{
        isEnabled: z.ZodBoolean;
        url: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        isEnabled: boolean;
        url?: string | undefined;
    }, {
        isEnabled: boolean;
        url?: string | undefined;
    }>>;
    hostBubbles: z.ZodObject<{
        backgroundColor: z.ZodString;
        color: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        color: string;
        backgroundColor: string;
    }, {
        color: string;
        backgroundColor: string;
    }>;
    guestBubbles: z.ZodObject<{
        backgroundColor: z.ZodString;
        color: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        color: string;
        backgroundColor: string;
    }, {
        color: string;
        backgroundColor: string;
    }>;
    buttons: z.ZodObject<{
        backgroundColor: z.ZodString;
        color: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        color: string;
        backgroundColor: string;
    }, {
        color: string;
        backgroundColor: string;
    }>;
    inputs: z.ZodObject<z.objectUtil.extendShape<{
        backgroundColor: z.ZodString;
        color: z.ZodString;
    }, {
        placeholderColor: z.ZodString;
    }>, "strip", z.ZodTypeAny, {
        color: string;
        backgroundColor: string;
        placeholderColor: string;
    }, {
        color: string;
        backgroundColor: string;
        placeholderColor: string;
    }>;
    roundness: z.ZodOptional<z.ZodEnum<["none", "medium", "large"]>>;
}, "strip", z.ZodTypeAny, {
    hostBubbles: {
        color: string;
        backgroundColor: string;
    };
    guestBubbles: {
        color: string;
        backgroundColor: string;
    };
    buttons: {
        color: string;
        backgroundColor: string;
    };
    inputs: {
        color: string;
        backgroundColor: string;
        placeholderColor: string;
    };
    hostAvatar?: {
        isEnabled: boolean;
        url?: string | undefined;
    } | undefined;
    guestAvatar?: {
        isEnabled: boolean;
        url?: string | undefined;
    } | undefined;
    roundness?: "medium" | "large" | "none" | undefined;
}, {
    hostBubbles: {
        color: string;
        backgroundColor: string;
    };
    guestBubbles: {
        color: string;
        backgroundColor: string;
    };
    buttons: {
        color: string;
        backgroundColor: string;
    };
    inputs: {
        color: string;
        backgroundColor: string;
        placeholderColor: string;
    };
    hostAvatar?: {
        isEnabled: boolean;
        url?: string | undefined;
    } | undefined;
    guestAvatar?: {
        isEnabled: boolean;
        url?: string | undefined;
    } | undefined;
    roundness?: "medium" | "large" | "none" | undefined;
}>;
declare const backgroundSchema: z.ZodObject<{
    type: z.ZodNativeEnum<typeof BackgroundType>;
    content: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: BackgroundType;
    content?: string | undefined;
}, {
    type: BackgroundType;
    content?: string | undefined;
}>;
declare const generalThemeSchema: z.ZodObject<{
    font: z.ZodString;
    background: z.ZodObject<{
        type: z.ZodNativeEnum<typeof BackgroundType>;
        content: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        type: BackgroundType;
        content?: string | undefined;
    }, {
        type: BackgroundType;
        content?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    font: string;
    background: {
        type: BackgroundType;
        content?: string | undefined;
    };
}, {
    font: string;
    background: {
        type: BackgroundType;
        content?: string | undefined;
    };
}>;
export declare const themeSchema: z.ZodObject<{
    general: z.ZodObject<{
        font: z.ZodString;
        background: z.ZodObject<{
            type: z.ZodNativeEnum<typeof BackgroundType>;
            content: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            type: BackgroundType;
            content?: string | undefined;
        }, {
            type: BackgroundType;
            content?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        font: string;
        background: {
            type: BackgroundType;
            content?: string | undefined;
        };
    }, {
        font: string;
        background: {
            type: BackgroundType;
            content?: string | undefined;
        };
    }>;
    chat: z.ZodObject<{
        hostAvatar: z.ZodOptional<z.ZodObject<{
            isEnabled: z.ZodBoolean;
            url: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            isEnabled: boolean;
            url?: string | undefined;
        }, {
            isEnabled: boolean;
            url?: string | undefined;
        }>>;
        guestAvatar: z.ZodOptional<z.ZodObject<{
            isEnabled: z.ZodBoolean;
            url: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            isEnabled: boolean;
            url?: string | undefined;
        }, {
            isEnabled: boolean;
            url?: string | undefined;
        }>>;
        hostBubbles: z.ZodObject<{
            backgroundColor: z.ZodString;
            color: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            color: string;
            backgroundColor: string;
        }, {
            color: string;
            backgroundColor: string;
        }>;
        guestBubbles: z.ZodObject<{
            backgroundColor: z.ZodString;
            color: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            color: string;
            backgroundColor: string;
        }, {
            color: string;
            backgroundColor: string;
        }>;
        buttons: z.ZodObject<{
            backgroundColor: z.ZodString;
            color: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            color: string;
            backgroundColor: string;
        }, {
            color: string;
            backgroundColor: string;
        }>;
        inputs: z.ZodObject<z.objectUtil.extendShape<{
            backgroundColor: z.ZodString;
            color: z.ZodString;
        }, {
            placeholderColor: z.ZodString;
        }>, "strip", z.ZodTypeAny, {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        }, {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        }>;
        roundness: z.ZodOptional<z.ZodEnum<["none", "medium", "large"]>>;
    }, "strip", z.ZodTypeAny, {
        hostBubbles: {
            color: string;
            backgroundColor: string;
        };
        guestBubbles: {
            color: string;
            backgroundColor: string;
        };
        buttons: {
            color: string;
            backgroundColor: string;
        };
        inputs: {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        };
        hostAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        guestAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        roundness?: "medium" | "large" | "none" | undefined;
    }, {
        hostBubbles: {
            color: string;
            backgroundColor: string;
        };
        guestBubbles: {
            color: string;
            backgroundColor: string;
        };
        buttons: {
            color: string;
            backgroundColor: string;
        };
        inputs: {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        };
        hostAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        guestAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        roundness?: "medium" | "large" | "none" | undefined;
    }>;
    customCss: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    general: {
        font: string;
        background: {
            type: BackgroundType;
            content?: string | undefined;
        };
    };
    chat: {
        hostBubbles: {
            color: string;
            backgroundColor: string;
        };
        guestBubbles: {
            color: string;
            backgroundColor: string;
        };
        buttons: {
            color: string;
            backgroundColor: string;
        };
        inputs: {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        };
        hostAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        guestAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        roundness?: "medium" | "large" | "none" | undefined;
    };
    customCss?: string | undefined;
}, {
    general: {
        font: string;
        background: {
            type: BackgroundType;
            content?: string | undefined;
        };
    };
    chat: {
        hostBubbles: {
            color: string;
            backgroundColor: string;
        };
        guestBubbles: {
            color: string;
            backgroundColor: string;
        };
        buttons: {
            color: string;
            backgroundColor: string;
        };
        inputs: {
            color: string;
            backgroundColor: string;
            placeholderColor: string;
        };
        hostAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        guestAvatar?: {
            isEnabled: boolean;
            url?: string | undefined;
        } | undefined;
        roundness?: "medium" | "large" | "none" | undefined;
    };
    customCss?: string | undefined;
}>;
export declare const defaultTheme: Theme;
export type Theme = z.infer<typeof themeSchema>;
export type ChatTheme = z.infer<typeof chatThemeSchema>;
export type AvatarProps = z.infer<typeof avatarPropsSchema>;
export type GeneralTheme = z.infer<typeof generalThemeSchema>;
export type Background = z.infer<typeof backgroundSchema>;
export type ContainerColors = z.infer<typeof containerColorsSchema>;
export type InputColors = z.infer<typeof inputColorsSchema>;
export {};
//# sourceMappingURL=schemas.d.ts.map