import { z } from 'zod';
import { InputBlockType } from '../enums';
import { PaymentProvider } from './enums';
export type CreditCardDetails = {
    number: string;
    exp_month: string;
    exp_year: string;
    cvc: string;
};
export declare const paymentInputOptionsSchema: z.ZodObject<z.objectUtil.extendShape<{
    variableId: z.ZodOptional<z.ZodString>;
}, {
    provider: z.ZodNativeEnum<typeof PaymentProvider>;
    labels: z.ZodObject<{
        button: z.ZodString;
        success: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        button: string;
        success?: string | undefined;
    }, {
        button: string;
        success?: string | undefined;
    }>;
    additionalInformation: z.ZodOptional<z.ZodObject<{
        description: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        email: z.ZodOptional<z.ZodString>;
        phoneNumber: z.ZodOptional<z.ZodString>;
        address: z.ZodOptional<z.ZodObject<{
            country: z.ZodOptional<z.ZodString>;
            line1: z.ZodOptional<z.ZodString>;
            line2: z.ZodOptional<z.ZodString>;
            state: z.ZodOptional<z.ZodString>;
            city: z.ZodOptional<z.ZodString>;
            postalCode: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        }, {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        address?: {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        } | undefined;
        description?: string | undefined;
        name?: string | undefined;
        email?: string | undefined;
        phoneNumber?: string | undefined;
    }, {
        address?: {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        } | undefined;
        description?: string | undefined;
        name?: string | undefined;
        email?: string | undefined;
        phoneNumber?: string | undefined;
    }>>;
    credentialsId: z.ZodOptional<z.ZodString>;
    currency: z.ZodString;
    amount: z.ZodOptional<z.ZodString>;
    retryMessageContent: z.ZodOptional<z.ZodString>;
}>, "strip", z.ZodTypeAny, {
    labels: {
        button: string;
        success?: string | undefined;
    };
    provider: PaymentProvider;
    currency: string;
    variableId?: string | undefined;
    retryMessageContent?: string | undefined;
    additionalInformation?: {
        address?: {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        } | undefined;
        description?: string | undefined;
        name?: string | undefined;
        email?: string | undefined;
        phoneNumber?: string | undefined;
    } | undefined;
    credentialsId?: string | undefined;
    amount?: string | undefined;
}, {
    labels: {
        button: string;
        success?: string | undefined;
    };
    provider: PaymentProvider;
    currency: string;
    variableId?: string | undefined;
    retryMessageContent?: string | undefined;
    additionalInformation?: {
        address?: {
            country?: string | undefined;
            line1?: string | undefined;
            line2?: string | undefined;
            state?: string | undefined;
            city?: string | undefined;
            postalCode?: string | undefined;
        } | undefined;
        description?: string | undefined;
        name?: string | undefined;
        email?: string | undefined;
        phoneNumber?: string | undefined;
    } | undefined;
    credentialsId?: string | undefined;
    amount?: string | undefined;
}>;
export declare const paymentInputRuntimeOptionsSchema: z.ZodObject<{
    paymentIntentSecret: z.ZodString;
    amountLabel: z.ZodString;
    publicKey: z.ZodString;
}, "strip", z.ZodTypeAny, {
    paymentIntentSecret: string;
    amountLabel: string;
    publicKey: string;
}, {
    paymentIntentSecret: string;
    amountLabel: string;
    publicKey: string;
}>;
export declare const paymentInputSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodString;
    groupId: z.ZodString;
    outgoingEdgeId: z.ZodOptional<z.ZodString>;
}, {
    type: z.ZodEnum<[InputBlockType.PAYMENT]>;
    options: z.ZodObject<z.objectUtil.extendShape<{
        variableId: z.ZodOptional<z.ZodString>;
    }, {
        provider: z.ZodNativeEnum<typeof PaymentProvider>;
        labels: z.ZodObject<{
            button: z.ZodString;
            success: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            button: string;
            success?: string | undefined;
        }, {
            button: string;
            success?: string | undefined;
        }>;
        additionalInformation: z.ZodOptional<z.ZodObject<{
            description: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            email: z.ZodOptional<z.ZodString>;
            phoneNumber: z.ZodOptional<z.ZodString>;
            address: z.ZodOptional<z.ZodObject<{
                country: z.ZodOptional<z.ZodString>;
                line1: z.ZodOptional<z.ZodString>;
                line2: z.ZodOptional<z.ZodString>;
                state: z.ZodOptional<z.ZodString>;
                city: z.ZodOptional<z.ZodString>;
                postalCode: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            }, {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        }, {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        }>>;
        credentialsId: z.ZodOptional<z.ZodString>;
        currency: z.ZodString;
        amount: z.ZodOptional<z.ZodString>;
        retryMessageContent: z.ZodOptional<z.ZodString>;
    }>, "strip", z.ZodTypeAny, {
        labels: {
            button: string;
            success?: string | undefined;
        };
        provider: PaymentProvider;
        currency: string;
        variableId?: string | undefined;
        retryMessageContent?: string | undefined;
        additionalInformation?: {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        } | undefined;
        credentialsId?: string | undefined;
        amount?: string | undefined;
    }, {
        labels: {
            button: string;
            success?: string | undefined;
        };
        provider: PaymentProvider;
        currency: string;
        variableId?: string | undefined;
        retryMessageContent?: string | undefined;
        additionalInformation?: {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        } | undefined;
        credentialsId?: string | undefined;
        amount?: string | undefined;
    }>;
}>, "strip", z.ZodTypeAny, {
    id: string;
    groupId: string;
    options: {
        labels: {
            button: string;
            success?: string | undefined;
        };
        provider: PaymentProvider;
        currency: string;
        variableId?: string | undefined;
        retryMessageContent?: string | undefined;
        additionalInformation?: {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        } | undefined;
        credentialsId?: string | undefined;
        amount?: string | undefined;
    };
    type: InputBlockType.PAYMENT;
    outgoingEdgeId?: string | undefined;
}, {
    id: string;
    groupId: string;
    options: {
        labels: {
            button: string;
            success?: string | undefined;
        };
        provider: PaymentProvider;
        currency: string;
        variableId?: string | undefined;
        retryMessageContent?: string | undefined;
        additionalInformation?: {
            address?: {
                country?: string | undefined;
                line1?: string | undefined;
                line2?: string | undefined;
                state?: string | undefined;
                city?: string | undefined;
                postalCode?: string | undefined;
            } | undefined;
            description?: string | undefined;
            name?: string | undefined;
            email?: string | undefined;
            phoneNumber?: string | undefined;
        } | undefined;
        credentialsId?: string | undefined;
        amount?: string | undefined;
    };
    type: InputBlockType.PAYMENT;
    outgoingEdgeId?: string | undefined;
}>;
export declare const defaultPaymentInputOptions: PaymentInputOptions;
export type PaymentInputBlock = z.infer<typeof paymentInputSchema>;
export type PaymentInputOptions = z.infer<typeof paymentInputOptionsSchema>;
export type PaymentInputRuntimeOptions = z.infer<typeof paymentInputRuntimeOptionsSchema>;
export type PaymentAddress = NonNullable<PaymentInputOptions['additionalInformation']>['address'];
//# sourceMappingURL=schemas.d.ts.map