import { z } from 'zod';
import { BubbleBlockType } from './blocks/bubbles/enums';
declare const chatMessageSchema: z.ZodObject<{
    id: z.ZodString;
    role: z.ZodOptional<z.ZodEnum<["assistant", "user"]>>;
    type: z.ZodEnum<[BubbleBlockType.TEXT, BubbleBlockType.IMAGE, BubbleBlockType.VIDEO, BubbleBlockType.AUDIO, BubbleBlockType.EMBED]>;
    content: z.ZodUnion<[z.ZodObject<{
        html: z.ZodOptional<z.ZodString>;
        richText: z.ZodArray<z.ZodAny, "many">;
        plainText: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        richText: any[];
        html?: string | undefined;
        plainText?: string | undefined;
    }, {
        richText: any[];
        html?: string | undefined;
        plainText?: string | undefined;
    }>, z.ZodObject<{
        url: z.ZodOptional<z.ZodString>;
        clickLink: z.ZodOptional<z.ZodObject<{
            url: z.ZodOptional<z.ZodString>;
            alt: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            url?: string | undefined;
            alt?: string | undefined;
        }, {
            url?: string | undefined;
            alt?: string | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        url?: string | undefined;
        clickLink?: {
            url?: string | undefined;
            alt?: string | undefined;
        } | undefined;
    }, {
        url?: string | undefined;
        clickLink?: {
            url?: string | undefined;
            alt?: string | undefined;
        } | undefined;
    }>, z.ZodObject<{
        url: z.ZodOptional<z.ZodString>;
        id: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").VideoBubbleContentType>>;
    }, "strip", z.ZodTypeAny, {
        url?: string | undefined;
        id?: string | undefined;
        type?: import("./blocks").VideoBubbleContentType | undefined;
    }, {
        url?: string | undefined;
        id?: string | undefined;
        type?: import("./blocks").VideoBubbleContentType | undefined;
    }>, z.ZodObject<{
        url: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        url?: string | undefined;
    }, {
        url?: string | undefined;
    }>, z.ZodObject<{
        url: z.ZodOptional<z.ZodString>;
        height: z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>;
    }, "strip", z.ZodTypeAny, {
        height: number | `{{${string}}}`;
        url?: string | undefined;
    }, {
        height: number | `{{${string}}}`;
        url?: string | undefined;
    }>]>;
}, "strip", z.ZodTypeAny, {
    id: string;
    type: BubbleBlockType;
    content: {
        url?: string | undefined;
    } | {
        height: number | `{{${string}}}`;
        url?: string | undefined;
    } | {
        url?: string | undefined;
        clickLink?: {
            url?: string | undefined;
            alt?: string | undefined;
        } | undefined;
    } | {
        richText: any[];
        html?: string | undefined;
        plainText?: string | undefined;
    } | {
        url?: string | undefined;
        id?: string | undefined;
        type?: import("./blocks").VideoBubbleContentType | undefined;
    };
    role?: "assistant" | "user" | undefined;
}, {
    id: string;
    type: BubbleBlockType;
    content: {
        url?: string | undefined;
    } | {
        height: number | `{{${string}}}`;
        url?: string | undefined;
    } | {
        url?: string | undefined;
        clickLink?: {
            url?: string | undefined;
            alt?: string | undefined;
        } | undefined;
    } | {
        richText: any[];
        html?: string | undefined;
        plainText?: string | undefined;
    } | {
        url?: string | undefined;
        id?: string | undefined;
        type?: import("./blocks").VideoBubbleContentType | undefined;
    };
    role?: "assistant" | "user" | undefined;
}>;
declare const scriptToExecuteSchema: z.ZodObject<{
    content: z.ZodString;
    args: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodNumber]>, z.ZodBoolean]>, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        value?: string | number | boolean | (string | null)[] | null | undefined;
    }, {
        id: string;
        value?: string | number | boolean | (string | null)[] | null | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    content: string;
    args: {
        id: string;
        value?: string | number | boolean | (string | null)[] | null | undefined;
    }[];
}, {
    content: string;
    args: {
        id: string;
        value?: string | number | boolean | (string | null)[] | null | undefined;
    }[];
}>;
declare const startAgentSchema: z.ZodObject<Pick<{
    version: z.ZodNullable<z.ZodEnum<["3"]>>;
    id: z.ZodString;
    name: z.ZodString;
    groups: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        title: z.ZodString;
        graphCoordinates: z.ZodObject<{
            x: z.ZodNumber;
            y: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            x: number;
            y: number;
        }, {
            x: number;
            y: number;
        }>;
        blocks: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodLiteral<"start">;
            label: z.ZodString;
        }>, "strip", z.ZodTypeAny, {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        }, {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[BubbleBlockType.TEXT]>;
            content: z.ZodObject<{
                html: z.ZodOptional<z.ZodString>;
                richText: z.ZodArray<z.ZodAny, "many">;
                plainText: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            }, {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[BubbleBlockType.IMAGE]>;
            content: z.ZodObject<{
                url: z.ZodOptional<z.ZodString>;
                clickLink: z.ZodOptional<z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                    alt: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    url?: string | undefined;
                    alt?: string | undefined;
                }, {
                    url?: string | undefined;
                    alt?: string | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            }, {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[BubbleBlockType.VIDEO]>;
            content: z.ZodObject<{
                url: z.ZodOptional<z.ZodString>;
                id: z.ZodOptional<z.ZodString>;
                type: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").VideoBubbleContentType>>;
            }, "strip", z.ZodTypeAny, {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            }, {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[BubbleBlockType.EMBED]>;
            content: z.ZodObject<{
                url: z.ZodOptional<z.ZodString>;
                height: z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>;
            }, "strip", z.ZodTypeAny, {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            }, {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[BubbleBlockType.AUDIO]>;
            content: z.ZodObject<{
                url: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                url?: string | undefined;
            }, {
                url?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.TEXT]>;
            options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                }, {
                    button: string;
                    placeholder: string;
                }>;
            }, {
                variableId: z.ZodOptional<z.ZodString>;
            }>, {
                isLong: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.CHOICE]>;
            items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                blockId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./items").ItemType.BUTTON>;
                content: z.ZodOptional<z.ZodString>;
                isUrl: z.ZodOptional<z.ZodBoolean>;
                displayCondition: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodOptional<z.ZodBoolean>;
                    condition: z.ZodOptional<z.ZodObject<{
                        logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                        comparisons: z.ZodArray<z.ZodObject<{
                            id: z.ZodString;
                            variableId: z.ZodOptional<z.ZodString>;
                            comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                            value: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                }, {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                }>>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }, {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }>, "many">;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                isMultipleChoice: z.ZodBoolean;
                buttonLabel: z.ZodString;
                dynamicVariableId: z.ZodOptional<z.ZodString>;
                isSearchable: z.ZodOptional<z.ZodBoolean>;
                searchInputPlaceholder: z.ZodOptional<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            }, {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.EMAIL]>;
            options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                }, {
                    button: string;
                    placeholder: string;
                }>;
            }>, {
                retryMessageContent: z.ZodString;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.NUMBER]>;
            options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                }, {
                    button: string;
                    placeholder: string;
                }>;
            }>, {
                min: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                max: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                step: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.URL]>;
            options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                }, {
                    button: string;
                    placeholder: string;
                }>;
            }>, {
                retryMessageContent: z.ZodString;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.PHONE]>;
            options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                }, {
                    button: string;
                    placeholder: string;
                }>;
            }>, {
                retryMessageContent: z.ZodString;
                defaultCountryCode: z.ZodOptional<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.DATE]>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                labels: z.ZodObject<{
                    button: z.ZodString;
                    from: z.ZodString;
                    to: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    from: string;
                    to: string;
                }, {
                    button: string;
                    from: string;
                    to: string;
                }>;
                hasTime: z.ZodBoolean;
                isRange: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            }, {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.PAYMENT]>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                provider: z.ZodNativeEnum<typeof import("./blocks").PaymentProvider>;
                labels: z.ZodObject<{
                    button: z.ZodString;
                    success: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    success?: string | undefined;
                }, {
                    button: string;
                    success?: string | undefined;
                }>;
                additionalInformation: z.ZodOptional<z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    name: z.ZodOptional<z.ZodString>;
                    email: z.ZodOptional<z.ZodString>;
                    phoneNumber: z.ZodOptional<z.ZodString>;
                    address: z.ZodOptional<z.ZodObject<{
                        country: z.ZodOptional<z.ZodString>;
                        line1: z.ZodOptional<z.ZodString>;
                        line2: z.ZodOptional<z.ZodString>;
                        state: z.ZodOptional<z.ZodString>;
                        city: z.ZodOptional<z.ZodString>;
                        postalCode: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    }, {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                }, {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                }>>;
                credentialsId: z.ZodOptional<z.ZodString>;
                currency: z.ZodString;
                amount: z.ZodOptional<z.ZodString>;
                retryMessageContent: z.ZodOptional<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            }, {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodLiteral<import("./blocks").InputBlockType.RATING>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                buttonType: z.ZodUnion<[z.ZodLiteral<"Icons">, z.ZodLiteral<"Numbers">]>;
                length: z.ZodNumber;
                labels: z.ZodObject<{
                    left: z.ZodOptional<z.ZodString>;
                    right: z.ZodOptional<z.ZodString>;
                    button: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                }, {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                }>;
                customIcon: z.ZodObject<{
                    isEnabled: z.ZodBoolean;
                    svg: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled: boolean;
                    svg?: string | undefined;
                }, {
                    isEnabled: boolean;
                    svg?: string | undefined;
                }>;
                isOneClickSubmitEnabled: z.ZodOptional<z.ZodBoolean>;
            }>, "strip", z.ZodTypeAny, {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            }, {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodLiteral<import("./blocks").InputBlockType.FILE>;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                isRequired: z.ZodOptional<z.ZodBoolean>;
                isMultipleAllowed: z.ZodBoolean;
                labels: z.ZodObject<{
                    placeholder: z.ZodString;
                    button: z.ZodString;
                    clear: z.ZodOptional<z.ZodString>;
                    skip: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                }, {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                }>;
                sizeLimit: z.ZodOptional<z.ZodNumber>;
            }>, "strip", z.ZodTypeAny, {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            }, {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").InputBlockType.PICTURE_CHOICE]>;
            items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                blockId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./items").ItemType.PICTURE_CHOICE>;
                pictureSrc: z.ZodOptional<z.ZodString>;
                title: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                displayCondition: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodOptional<z.ZodBoolean>;
                    condition: z.ZodOptional<z.ZodObject<{
                        logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                        comparisons: z.ZodArray<z.ZodObject<{
                            id: z.ZodString;
                            variableId: z.ZodOptional<z.ZodString>;
                            comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                            value: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                }, {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                }>>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }, {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }>, "many">;
            options: z.ZodObject<z.objectUtil.extendShape<{
                variableId: z.ZodOptional<z.ZodString>;
            }, {
                isMultipleChoice: z.ZodOptional<z.ZodBoolean>;
                isSearchable: z.ZodOptional<z.ZodBoolean>;
                buttonLabel: z.ZodString;
                searchInputPlaceholder: z.ZodString;
                dynamicItems: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodOptional<z.ZodBoolean>;
                    titlesVariableId: z.ZodOptional<z.ZodString>;
                    descriptionsVariableId: z.ZodOptional<z.ZodString>;
                    pictureSrcsVariableId: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                }, {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                }>>;
            }>, "strip", z.ZodTypeAny, {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            }, {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.SCRIPT]>;
            options: z.ZodObject<{
                name: z.ZodString;
                content: z.ZodOptional<z.ZodString>;
                shouldExecuteInParentContext: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            }, {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.CONDITION]>;
            items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                blockId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./items").ItemType.CONDITION>;
                content: z.ZodObject<{
                    logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                    comparisons: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        variableId: z.ZodOptional<z.ZodString>;
                        comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                        value: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }, {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                }, {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }>, "many">;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.REDIRECT]>;
            options: z.ZodObject<{
                url: z.ZodOptional<z.ZodString>;
                isNewTab: z.ZodBoolean;
            }, "strip", z.ZodTypeAny, {
                isNewTab: boolean;
                url?: string | undefined;
            }, {
                isNewTab: boolean;
                url?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.SET_VARIABLE]>;
            options: z.ZodObject<{
                variableId: z.ZodOptional<z.ZodString>;
                expressionToEvaluate: z.ZodOptional<z.ZodString>;
                isCode: z.ZodOptional<z.ZodBoolean>;
                type: z.ZodOptional<z.ZodEnum<["Custom", "Empty", "User ID", "Today", "Yesterday", "Tomorrow", "Random ID", "Moment of the day", "Map item with same index"]>>;
                mapListItemParams: z.ZodOptional<z.ZodObject<{
                    baseItemVariableId: z.ZodOptional<z.ZodString>;
                    baseListVariableId: z.ZodOptional<z.ZodString>;
                    targetListVariableId: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                }, {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                }>>;
                isExecutedOnClient: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            }, {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.AGENT_LINK]>;
            options: z.ZodObject<{
                agentId: z.ZodOptional<z.ZodString>;
                groupId: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                groupId?: string | undefined;
                agentId?: string | undefined;
            }, {
                groupId?: string | undefined;
                agentId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.WAIT]>;
            options: z.ZodObject<{
                secondsToWaitFor: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                secondsToWaitFor?: string | undefined;
            }, {
                secondsToWaitFor?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.JUMP]>;
            options: z.ZodObject<{
                groupId: z.ZodOptional<z.ZodString>;
                blockId: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                groupId?: string | undefined;
                blockId?: string | undefined;
            }, {
                groupId?: string | undefined;
                blockId?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").LogicBlockType.AB_TEST]>;
            items: z.ZodTuple<[z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                blockId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./items").ItemType.AB_TEST>;
                path: z.ZodLiteral<"a">;
            }>, "strip", z.ZodTypeAny, {
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                blockId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./items").ItemType.AB_TEST>;
                path: z.ZodLiteral<"b">;
            }>, "strip", z.ZodTypeAny, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }>], null>;
            options: z.ZodObject<{
                aPercent: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                aPercent: number;
            }, {
                aPercent: number;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS]>;
            options: z.ZodObject<{
                trackingId: z.ZodOptional<z.ZodString>;
                category: z.ZodOptional<z.ZodString>;
                action: z.ZodOptional<z.ZodString>;
                label: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                sendTo: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            }, {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            id: z.ZodString;
            groupId: z.ZodString;
            outgoingEdgeId: z.ZodOptional<z.ZodString>;
        }, {
            type: z.ZodEnum<[import("./blocks").IntegrationBlockType.PIXEL]>;
            options: z.ZodDiscriminatedUnion<"eventType", [z.ZodObject<z.objectUtil.extendShape<{
                pixelId: z.ZodOptional<z.ZodString>;
                isInitSkip: z.ZodOptional<z.ZodBoolean>;
                params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    key: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                }, "strip", z.ZodTypeAny, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }>, "many">>;
            }, {
                eventType: z.ZodUndefined;
            }>, "strip", z.ZodTypeAny, {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            }, {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                pixelId: z.ZodOptional<z.ZodString>;
                isInitSkip: z.ZodOptional<z.ZodBoolean>;
                params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    key: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                }, "strip", z.ZodTypeAny, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }>, "many">>;
            }, {
                eventType: z.ZodEnum<["Lead", "Contact", "CompleteRegistration", "Schedule", "SubmitApplication", "ViewContent", "AddPaymentInfo", "AddToCart", "AddToWishlist", "CustomizeProduct", "Donate", "FindLocation", "InitiateCheckout", "Purchase", "Search", "StartTrial", "Subscribe"]>;
            }>, "strip", z.ZodTypeAny, {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            }, {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                pixelId: z.ZodOptional<z.ZodString>;
                isInitSkip: z.ZodOptional<z.ZodBoolean>;
                params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    key: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                }, "strip", z.ZodTypeAny, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }, {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }>, "many">>;
            }, {
                eventType: z.ZodEnum<["Custom"]>;
                name: z.ZodOptional<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            }, {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            }>]>;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        }, {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        }>]>, "many">;
    }, "strip", z.ZodTypeAny, {
        title: string;
        id: string;
        graphCoordinates: {
            x: number;
            y: number;
        };
        blocks: ({
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        } | {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        })[];
    }, {
        title: string;
        id: string;
        graphCoordinates: {
            x: number;
            y: number;
        };
        blocks: ({
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        } | {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        })[];
    }>, "many">;
    edges: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        from: z.ZodObject<{
            groupId: z.ZodString;
            blockId: z.ZodString;
            itemId: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        }, {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        }>;
        to: z.ZodObject<{
            groupId: z.ZodString;
            blockId: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            groupId: string;
            blockId?: string | undefined;
        }, {
            groupId: string;
            blockId?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        from: {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        };
        to: {
            groupId: string;
            blockId?: string | undefined;
        };
    }, {
        id: string;
        from: {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        };
        to: {
            groupId: string;
            blockId?: string | undefined;
        };
    }>, "many">;
    variables: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        name: string;
        value?: string | (string | null)[] | null | undefined;
    }, {
        id: string;
        name: string;
        value?: string | (string | null)[] | null | undefined;
    }>, "many">;
    theme: z.ZodObject<{
        general: z.ZodObject<{
            font: z.ZodString;
            background: z.ZodObject<{
                type: z.ZodNativeEnum<typeof import("./agent").BackgroundType>;
                content: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            }, {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        }, {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        }>;
        chat: z.ZodObject<{
            hostAvatar: z.ZodOptional<z.ZodObject<{
                isEnabled: z.ZodBoolean;
                url: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                isEnabled: boolean;
                url?: string | undefined;
            }, {
                isEnabled: boolean;
                url?: string | undefined;
            }>>;
            guestAvatar: z.ZodOptional<z.ZodObject<{
                isEnabled: z.ZodBoolean;
                url: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                isEnabled: boolean;
                url?: string | undefined;
            }, {
                isEnabled: boolean;
                url?: string | undefined;
            }>>;
            hostBubbles: z.ZodObject<{
                backgroundColor: z.ZodString;
                color: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                color: string;
                backgroundColor: string;
            }, {
                color: string;
                backgroundColor: string;
            }>;
            guestBubbles: z.ZodObject<{
                backgroundColor: z.ZodString;
                color: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                color: string;
                backgroundColor: string;
            }, {
                color: string;
                backgroundColor: string;
            }>;
            buttons: z.ZodObject<{
                backgroundColor: z.ZodString;
                color: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                color: string;
                backgroundColor: string;
            }, {
                color: string;
                backgroundColor: string;
            }>;
            inputs: z.ZodObject<z.objectUtil.extendShape<{
                backgroundColor: z.ZodString;
                color: z.ZodString;
            }, {
                placeholderColor: z.ZodString;
            }>, "strip", z.ZodTypeAny, {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            }, {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            }>;
            roundness: z.ZodOptional<z.ZodEnum<["none", "medium", "large"]>>;
        }, "strip", z.ZodTypeAny, {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        }, {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        }>;
        customCss: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        general: {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        };
        chat: {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        };
        customCss?: string | undefined;
    }, {
        general: {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        };
        chat: {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        };
        customCss?: string | undefined;
    }>;
    selectedThemeTemplateId: z.ZodNullable<z.ZodString>;
    settings: z.ZodObject<{
        general: z.ZodObject<{
            isBrandingEnabled: z.ZodBoolean;
            isTypingEmulationEnabled: z.ZodOptional<z.ZodBoolean>;
            isInputPrefillEnabled: z.ZodOptional<z.ZodBoolean>;
            isHideQueryParamsEnabled: z.ZodOptional<z.ZodBoolean>;
            isNewResultOnRefreshEnabled: z.ZodOptional<z.ZodBoolean>;
            rememberUser: z.ZodOptional<z.ZodObject<{
                isEnabled: z.ZodOptional<z.ZodBoolean>;
                storage: z.ZodOptional<z.ZodEnum<["session", "local"]>>;
            }, "strip", z.ZodTypeAny, {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            }, {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        }, {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        }>;
        typingEmulation: z.ZodObject<{
            enabled: z.ZodBoolean;
            speed: z.ZodNumber;
            maxDelay: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        }, {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        }>;
        metadata: z.ZodObject<{
            title: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            imageUrl: z.ZodOptional<z.ZodString>;
            favIconUrl: z.ZodOptional<z.ZodString>;
            customHeadCode: z.ZodOptional<z.ZodString>;
            googleTagManagerId: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        }, {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        general: {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        };
        typingEmulation: {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        };
        metadata: {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        };
    }, {
        general: {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        };
        typingEmulation: {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        };
        metadata: {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        };
    }>;
    createdAt: z.ZodDate;
    updatedAt: z.ZodDate;
    icon: z.ZodNullable<z.ZodString>;
    folderId: z.ZodNullable<z.ZodString>;
    publicId: z.ZodNullable<z.ZodString>;
    customDomain: z.ZodNullable<z.ZodString>;
    workspaceId: z.ZodString;
    resultsTablePreferences: z.ZodNullable<z.ZodObject<{
        columnsOrder: z.ZodArray<z.ZodString, "many">;
        columnsVisibility: z.ZodRecord<z.ZodString, z.ZodBoolean>;
        columnsWidth: z.ZodRecord<z.ZodString, z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        columnsOrder: string[];
        columnsVisibility: Record<string, boolean>;
        columnsWidth: Record<string, number>;
    }, {
        columnsOrder: string[];
        columnsVisibility: Record<string, boolean>;
        columnsWidth: Record<string, number>;
    }>>;
    isArchived: z.ZodBoolean;
    isClosed: z.ZodBoolean;
}, "id" | "groups" | "edges" | "variables" | "theme" | "settings">, "strip", z.ZodTypeAny, {
    id: string;
    groups: {
        title: string;
        id: string;
        graphCoordinates: {
            x: number;
            y: number;
        };
        blocks: ({
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        } | {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        })[];
    }[];
    edges: {
        id: string;
        from: {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        };
        to: {
            groupId: string;
            blockId?: string | undefined;
        };
    }[];
    variables: {
        id: string;
        name: string;
        value?: string | (string | null)[] | null | undefined;
    }[];
    theme: {
        general: {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        };
        chat: {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        };
        customCss?: string | undefined;
    };
    settings: {
        general: {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        };
        typingEmulation: {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        };
        metadata: {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        };
    };
}, {
    id: string;
    groups: {
        title: string;
        id: string;
        graphCoordinates: {
            x: number;
            y: number;
        };
        blocks: ({
            id: string;
            groupId: string;
            type: BubbleBlockType.AUDIO;
            content: {
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.EMBED;
            content: {
                height: number | `{{${string}}}`;
                url?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.IMAGE;
            content: {
                url?: string | undefined;
                clickLink?: {
                    url?: string | undefined;
                    alt?: string | undefined;
                } | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.TEXT;
            content: {
                richText: any[];
                html?: string | undefined;
                plainText?: string | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: BubbleBlockType.VIDEO;
            content: {
                url?: string | undefined;
                id?: string | undefined;
                type?: import("./blocks").VideoBubbleContentType | undefined;
            };
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            type: import("./blocks").LogicBlockType.CONDITION;
            items: {
                id: string;
                type: import("./items").ItemType.CONDITION;
                content: {
                    logicalOperator: import("./blocks").LogicalOperator;
                    comparisons: {
                        id: string;
                        value?: string | undefined;
                        variableId?: string | undefined;
                        comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                    }[];
                };
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isMultipleChoice: boolean;
                buttonLabel: string;
                variableId?: string | undefined;
                dynamicVariableId?: string | undefined;
                isSearchable?: boolean | undefined;
                searchInputPlaceholder?: string | undefined;
            };
            type: import("./blocks").InputBlockType.CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.BUTTON;
                blockId: string;
                outgoingEdgeId?: string | undefined;
                content?: string | undefined;
                isUrl?: boolean | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    from: string;
                    to: string;
                };
                hasTime: boolean;
                isRange: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.DATE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                isLong: boolean;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.TEXT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.EMAIL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                    clear?: string | undefined;
                    skip?: string | undefined;
                };
                isMultipleAllowed: boolean;
                variableId?: string | undefined;
                isRequired?: boolean | undefined;
                sizeLimit?: number | undefined;
            };
            type: import("./blocks").InputBlockType.FILE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                variableId?: string | undefined;
                min?: number | `{{${string}}}` | undefined;
                max?: number | `{{${string}}}` | undefined;
                step?: number | `{{${string}}}` | undefined;
            };
            type: import("./blocks").InputBlockType.NUMBER;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    success?: string | undefined;
                };
                provider: import("./blocks").PaymentProvider;
                currency: string;
                variableId?: string | undefined;
                retryMessageContent?: string | undefined;
                additionalInformation?: {
                    address?: {
                        country?: string | undefined;
                        line1?: string | undefined;
                        line2?: string | undefined;
                        state?: string | undefined;
                        city?: string | undefined;
                        postalCode?: string | undefined;
                    } | undefined;
                    description?: string | undefined;
                    name?: string | undefined;
                    email?: string | undefined;
                    phoneNumber?: string | undefined;
                } | undefined;
                credentialsId?: string | undefined;
                amount?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PAYMENT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
                defaultCountryCode?: string | undefined;
            };
            type: import("./blocks").InputBlockType.PHONE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                length: number;
                labels: {
                    button: string;
                    left?: string | undefined;
                    right?: string | undefined;
                };
                buttonType: "Icons" | "Numbers";
                customIcon: {
                    isEnabled: boolean;
                    svg?: string | undefined;
                };
                variableId?: string | undefined;
                isOneClickSubmitEnabled?: boolean | undefined;
            };
            type: import("./blocks").InputBlockType.RATING;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                labels: {
                    button: string;
                    placeholder: string;
                };
                retryMessageContent: string;
                variableId?: string | undefined;
            };
            type: import("./blocks").InputBlockType.URL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                buttonLabel: string;
                searchInputPlaceholder: string;
                variableId?: string | undefined;
                isMultipleChoice?: boolean | undefined;
                isSearchable?: boolean | undefined;
                dynamicItems?: {
                    isEnabled?: boolean | undefined;
                    titlesVariableId?: string | undefined;
                    descriptionsVariableId?: string | undefined;
                    pictureSrcsVariableId?: string | undefined;
                } | undefined;
            };
            type: import("./blocks").InputBlockType.PICTURE_CHOICE;
            items: {
                id: string;
                type: import("./items").ItemType.PICTURE_CHOICE;
                blockId: string;
                title?: string | undefined;
                outgoingEdgeId?: string | undefined;
                displayCondition?: {
                    isEnabled?: boolean | undefined;
                    condition?: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                description?: string | undefined;
                pictureSrc?: string | undefined;
            }[];
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                value?: number | `{{${string}}}` | undefined;
                label?: string | undefined;
                trackingId?: string | undefined;
                category?: string | undefined;
                action?: string | undefined;
                sendTo?: string | undefined;
            };
            type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
                eventType?: undefined;
            } | {
                eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            } | {
                eventType: "Custom";
                params?: {
                    id: string;
                    value?: any;
                    key?: string | undefined;
                }[] | undefined;
                name?: string | undefined;
                pixelId?: string | undefined;
                isInitSkip?: boolean | undefined;
            };
            type: import("./blocks").IntegrationBlockType.PIXEL;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                name: string;
                content?: string | undefined;
                shouldExecuteInParentContext?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SCRIPT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                isNewTab: boolean;
                url?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.REDIRECT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                variableId?: string | undefined;
                expressionToEvaluate?: string | undefined;
                isCode?: boolean | undefined;
                mapListItemParams?: {
                    baseItemVariableId?: string | undefined;
                    baseListVariableId?: string | undefined;
                    targetListVariableId?: string | undefined;
                } | undefined;
                isExecutedOnClient?: boolean | undefined;
            };
            type: import("./blocks").LogicBlockType.SET_VARIABLE;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                agentId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.AGENT_LINK;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                secondsToWaitFor?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.WAIT;
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                aPercent: number;
            };
            type: import("./blocks").LogicBlockType.AB_TEST;
            items: [{
                path: "a";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }, {
                path: "b";
                id: string;
                type: import("./items").ItemType.AB_TEST;
                blockId: string;
                outgoingEdgeId?: string | undefined;
            }];
            outgoingEdgeId?: string | undefined;
        } | {
            label: string;
            id: string;
            groupId: string;
            type: "start";
            outgoingEdgeId?: string | undefined;
        } | {
            id: string;
            groupId: string;
            options: {
                groupId?: string | undefined;
                blockId?: string | undefined;
            };
            type: import("./blocks").LogicBlockType.JUMP;
            outgoingEdgeId?: string | undefined;
        })[];
    }[];
    edges: {
        id: string;
        from: {
            groupId: string;
            blockId: string;
            itemId?: string | undefined;
        };
        to: {
            groupId: string;
            blockId?: string | undefined;
        };
    }[];
    variables: {
        id: string;
        name: string;
        value?: string | (string | null)[] | null | undefined;
    }[];
    theme: {
        general: {
            font: string;
            background: {
                type: import("./agent").BackgroundType;
                content?: string | undefined;
            };
        };
        chat: {
            hostBubbles: {
                color: string;
                backgroundColor: string;
            };
            guestBubbles: {
                color: string;
                backgroundColor: string;
            };
            buttons: {
                color: string;
                backgroundColor: string;
            };
            inputs: {
                color: string;
                backgroundColor: string;
                placeholderColor: string;
            };
            hostAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            guestAvatar?: {
                isEnabled: boolean;
                url?: string | undefined;
            } | undefined;
            roundness?: "medium" | "large" | "none" | undefined;
        };
        customCss?: string | undefined;
    };
    settings: {
        general: {
            isBrandingEnabled: boolean;
            isTypingEmulationEnabled?: boolean | undefined;
            isInputPrefillEnabled?: boolean | undefined;
            isHideQueryParamsEnabled?: boolean | undefined;
            isNewResultOnRefreshEnabled?: boolean | undefined;
            rememberUser?: {
                isEnabled?: boolean | undefined;
                storage?: "session" | "local" | undefined;
            } | undefined;
        };
        typingEmulation: {
            enabled: boolean;
            speed: number;
            maxDelay: number;
        };
        metadata: {
            title?: string | undefined;
            description?: string | undefined;
            imageUrl?: string | undefined;
            favIconUrl?: string | undefined;
            customHeadCode?: string | undefined;
            googleTagManagerId?: string | undefined;
        };
    };
}>;
declare const startParamsSchema: z.ZodObject<{
    agentName: z.ZodOptional<z.ZodString>;
    isPreview: z.ZodOptional<z.ZodBoolean>;
    resultId: z.ZodOptional<z.ZodString>;
    startGroupId: z.ZodOptional<z.ZodString>;
    prefilledVariables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    isStreamEnabled: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    resultId?: string | undefined;
    agentName?: string | undefined;
    isPreview?: boolean | undefined;
    startGroupId?: string | undefined;
    prefilledVariables?: Record<string, unknown> | undefined;
    isStreamEnabled?: boolean | undefined;
}, {
    resultId?: string | undefined;
    agentName?: string | undefined;
    isPreview?: boolean | undefined;
    startGroupId?: string | undefined;
    prefilledVariables?: Record<string, unknown> | undefined;
    isStreamEnabled?: boolean | undefined;
}>;
declare const replyLogSchema: z.ZodObject<z.objectUtil.extendShape<Pick<{
    id: z.ZodString;
    createdAt: z.ZodDate;
    resultId: z.ZodString;
    status: z.ZodString;
    description: z.ZodString;
    details: z.ZodNullable<z.ZodString>;
}, "status" | "description">, {
    details: z.ZodOptional<z.ZodUnknown>;
}>, "strip", z.ZodTypeAny, {
    status: string;
    description: string;
    details?: unknown;
}, {
    status: string;
    description: string;
    details?: unknown;
}>;
export declare const sendMessageInputSchema: z.ZodObject<{
    message: z.ZodOptional<z.ZodString>;
    sessionId: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNull]>>;
    clientLogs: z.ZodOptional<z.ZodArray<z.ZodObject<z.objectUtil.extendShape<Pick<{
        id: z.ZodString;
        createdAt: z.ZodDate;
        resultId: z.ZodString;
        status: z.ZodString;
        description: z.ZodString;
        details: z.ZodNullable<z.ZodString>;
    }, "status" | "description">, {
        details: z.ZodOptional<z.ZodUnknown>;
    }>, "strip", z.ZodTypeAny, {
        status: string;
        description: string;
        details?: unknown;
    }, {
        status: string;
        description: string;
        details?: unknown;
    }>, "many">>;
    startParams: z.ZodOptional<z.ZodObject<{
        agentName: z.ZodOptional<z.ZodString>;
        isPreview: z.ZodOptional<z.ZodBoolean>;
        resultId: z.ZodOptional<z.ZodString>;
        startGroupId: z.ZodOptional<z.ZodString>;
        prefilledVariables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        isStreamEnabled: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        resultId?: string | undefined;
        agentName?: string | undefined;
        isPreview?: boolean | undefined;
        startGroupId?: string | undefined;
        prefilledVariables?: Record<string, unknown> | undefined;
        isStreamEnabled?: boolean | undefined;
    }, {
        resultId?: string | undefined;
        agentName?: string | undefined;
        isPreview?: boolean | undefined;
        startGroupId?: string | undefined;
        prefilledVariables?: Record<string, unknown> | undefined;
        isStreamEnabled?: boolean | undefined;
    }>>;
    agentName: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    message?: string | undefined;
    sessionId?: string | null | undefined;
    agentName?: string | undefined;
    clientLogs?: {
        status: string;
        description: string;
        details?: unknown;
    }[] | undefined;
    startParams?: {
        resultId?: string | undefined;
        agentName?: string | undefined;
        isPreview?: boolean | undefined;
        startGroupId?: string | undefined;
        prefilledVariables?: Record<string, unknown> | undefined;
        isStreamEnabled?: boolean | undefined;
    } | undefined;
}, {
    message?: string | undefined;
    sessionId?: string | null | undefined;
    agentName?: string | undefined;
    clientLogs?: {
        status: string;
        description: string;
        details?: unknown;
    }[] | undefined;
    startParams?: {
        resultId?: string | undefined;
        agentName?: string | undefined;
        isPreview?: boolean | undefined;
        startGroupId?: string | undefined;
        prefilledVariables?: Record<string, unknown> | undefined;
        isStreamEnabled?: boolean | undefined;
    } | undefined;
}>;
declare const runtimeOptionsSchema: z.ZodOptional<z.ZodObject<{
    paymentIntentSecret: z.ZodString;
    amountLabel: z.ZodString;
    publicKey: z.ZodString;
}, "strip", z.ZodTypeAny, {
    paymentIntentSecret: string;
    amountLabel: string;
    publicKey: string;
}, {
    paymentIntentSecret: string;
    amountLabel: string;
    publicKey: string;
}>>;
declare const startPropsToInjectSchema: z.ZodObject<{
    googleAnalyticsId: z.ZodOptional<z.ZodString>;
    pixelId: z.ZodOptional<z.ZodString>;
    gtmId: z.ZodOptional<z.ZodString>;
    customHeadCode: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    pixelId?: string | undefined;
    customHeadCode?: string | undefined;
    googleAnalyticsId?: string | undefined;
    gtmId?: string | undefined;
}, {
    pixelId?: string | undefined;
    customHeadCode?: string | undefined;
    googleAnalyticsId?: string | undefined;
    gtmId?: string | undefined;
}>;
export declare const chatReplySchema: z.ZodObject<{
    messages: z.ZodAny;
    input: z.ZodAny;
    clientSideActions: z.ZodOptional<z.ZodArray<z.ZodIntersection<z.ZodObject<{
        lastBubbleBlockId: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        lastBubbleBlockId?: string | undefined;
    }, {
        lastBubbleBlockId?: string | undefined;
    }>, z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodObject<{
        scriptToExecute: z.ZodObject<{
            content: z.ZodString;
            args: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodNumber]>, z.ZodBoolean]>, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
            }, "strip", z.ZodTypeAny, {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }, {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        }, {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        }>;
    }, "strip", z.ZodTypeAny, {
        scriptToExecute: {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        };
    }, {
        scriptToExecute: {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        };
    }>, z.ZodObject<{
        redirect: z.ZodObject<{
            url: z.ZodOptional<z.ZodString>;
            isNewTab: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            isNewTab: boolean;
            url?: string | undefined;
        }, {
            isNewTab: boolean;
            url?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        redirect: {
            isNewTab: boolean;
            url?: string | undefined;
        };
    }, {
        redirect: {
            isNewTab: boolean;
            url?: string | undefined;
        };
    }>]>, z.ZodObject<{
        chatwoot: z.ZodObject<{
            scriptToExecute: z.ZodObject<{
                content: z.ZodString;
                args: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodNumber]>, z.ZodBoolean]>, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
                }, "strip", z.ZodTypeAny, {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }, {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            }, {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            }>;
        }, "strip", z.ZodTypeAny, {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        }, {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        chatwoot: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    }, {
        chatwoot: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    }>]>, z.ZodObject<{
        googleAnalytics: z.ZodObject<{
            trackingId: z.ZodOptional<z.ZodString>;
            category: z.ZodOptional<z.ZodString>;
            action: z.ZodOptional<z.ZodString>;
            label: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
            sendTo: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        }, {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        googleAnalytics: {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        };
    }, {
        googleAnalytics: {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        };
    }>]>, z.ZodObject<{
        wait: z.ZodObject<{
            secondsToWaitFor: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            secondsToWaitFor: number;
        }, {
            secondsToWaitFor: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        wait: {
            secondsToWaitFor: number;
        };
    }, {
        wait: {
            secondsToWaitFor: number;
        };
    }>]>, z.ZodObject<{
        setVariable: z.ZodObject<{
            scriptToExecute: z.ZodObject<{
                content: z.ZodString;
                args: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodNumber]>, z.ZodBoolean]>, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
                }, "strip", z.ZodTypeAny, {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }, {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            }, {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            }>;
        }, "strip", z.ZodTypeAny, {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        }, {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        setVariable: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    }, {
        setVariable: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    }>]>, z.ZodObject<{
        streamOpenAiChatCompletion: z.ZodObject<{
            message: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            message?: string | undefined;
        }, {
            message?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        streamOpenAiChatCompletion: {
            message?: string | undefined;
        };
    }, {
        streamOpenAiChatCompletion: {
            message?: string | undefined;
        };
    }>]>, z.ZodObject<{
        startPropsToInject: z.ZodObject<{
            googleAnalyticsId: z.ZodOptional<z.ZodString>;
            pixelId: z.ZodOptional<z.ZodString>;
            gtmId: z.ZodOptional<z.ZodString>;
            customHeadCode: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        }, {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        startPropsToInject: {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        };
    }, {
        startPropsToInject: {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        };
    }>]>, z.ZodObject<{
        pixel: z.ZodDiscriminatedUnion<"eventType", [z.ZodObject<z.objectUtil.extendShape<{
            pixelId: z.ZodOptional<z.ZodString>;
            isInitSkip: z.ZodOptional<z.ZodBoolean>;
            params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                key: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
            }, "strip", z.ZodTypeAny, {
                id: string;
                value?: any;
                key?: string | undefined;
            }, {
                id: string;
                value?: any;
                key?: string | undefined;
            }>, "many">>;
        }, {
            eventType: z.ZodUndefined;
        }>, "strip", z.ZodTypeAny, {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        }, {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            pixelId: z.ZodOptional<z.ZodString>;
            isInitSkip: z.ZodOptional<z.ZodBoolean>;
            params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                key: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
            }, "strip", z.ZodTypeAny, {
                id: string;
                value?: any;
                key?: string | undefined;
            }, {
                id: string;
                value?: any;
                key?: string | undefined;
            }>, "many">>;
        }, {
            eventType: z.ZodEnum<["Lead", "Contact", "CompleteRegistration", "Schedule", "SubmitApplication", "ViewContent", "AddPaymentInfo", "AddToCart", "AddToWishlist", "CustomizeProduct", "Donate", "FindLocation", "InitiateCheckout", "Purchase", "Search", "StartTrial", "Subscribe"]>;
        }>, "strip", z.ZodTypeAny, {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        }, {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            pixelId: z.ZodOptional<z.ZodString>;
            isInitSkip: z.ZodOptional<z.ZodBoolean>;
            params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                key: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
            }, "strip", z.ZodTypeAny, {
                id: string;
                value?: any;
                key?: string | undefined;
            }, {
                id: string;
                value?: any;
                key?: string | undefined;
            }>, "many">>;
        }, {
            eventType: z.ZodEnum<["Custom"]>;
            name: z.ZodOptional<z.ZodString>;
        }>, "strip", z.ZodTypeAny, {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        }, {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        }>]>;
    }, "strip", z.ZodTypeAny, {
        pixel: {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        } | {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        } | {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        };
    }, {
        pixel: {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        } | {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        } | {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        };
    }>]>>, "many">>;
    sessionId: z.ZodOptional<z.ZodString>;
    agentConfig: z.ZodOptional<z.ZodObject<Pick<{
        version: z.ZodNullable<z.ZodEnum<["3"]>>;
        id: z.ZodString;
        name: z.ZodString;
        groups: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            title: z.ZodString;
            graphCoordinates: z.ZodObject<{
                x: z.ZodNumber;
                y: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                x: number;
                y: number;
            }, {
                x: number;
                y: number;
            }>;
            blocks: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<"start">;
                label: z.ZodString;
            }>, "strip", z.ZodTypeAny, {
                label: string;
                id: string;
                groupId: string;
                type: "start";
                outgoingEdgeId?: string | undefined;
            }, {
                label: string;
                id: string;
                groupId: string;
                type: "start";
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[BubbleBlockType.TEXT]>;
                content: z.ZodObject<{
                    html: z.ZodOptional<z.ZodString>;
                    richText: z.ZodArray<z.ZodAny, "many">;
                    plainText: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                }, {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: BubbleBlockType.TEXT;
                content: {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: BubbleBlockType.TEXT;
                content: {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[BubbleBlockType.IMAGE]>;
                content: z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                    clickLink: z.ZodOptional<z.ZodObject<{
                        url: z.ZodOptional<z.ZodString>;
                        alt: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        url?: string | undefined;
                        alt?: string | undefined;
                    }, {
                        url?: string | undefined;
                        alt?: string | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                }, {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: BubbleBlockType.IMAGE;
                content: {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: BubbleBlockType.IMAGE;
                content: {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[BubbleBlockType.VIDEO]>;
                content: z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                    id: z.ZodOptional<z.ZodString>;
                    type: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").VideoBubbleContentType>>;
                }, "strip", z.ZodTypeAny, {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                }, {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: BubbleBlockType.VIDEO;
                content: {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: BubbleBlockType.VIDEO;
                content: {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[BubbleBlockType.EMBED]>;
                content: z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                    height: z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>;
                }, "strip", z.ZodTypeAny, {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                }, {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: BubbleBlockType.EMBED;
                content: {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: BubbleBlockType.EMBED;
                content: {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[BubbleBlockType.AUDIO]>;
                content: z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    url?: string | undefined;
                }, {
                    url?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: BubbleBlockType.AUDIO;
                content: {
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: BubbleBlockType.AUDIO;
                content: {
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.TEXT]>;
                options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                    }, {
                        button: string;
                        placeholder: string;
                    }>;
                }, {
                    variableId: z.ZodOptional<z.ZodString>;
                }>, {
                    isLong: z.ZodBoolean;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.TEXT;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.TEXT;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.CHOICE]>;
                items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                    id: z.ZodString;
                    blockId: z.ZodString;
                    outgoingEdgeId: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<import("./items").ItemType.BUTTON>;
                    content: z.ZodOptional<z.ZodString>;
                    isUrl: z.ZodOptional<z.ZodBoolean>;
                    displayCondition: z.ZodOptional<z.ZodObject<{
                        isEnabled: z.ZodOptional<z.ZodBoolean>;
                        condition: z.ZodOptional<z.ZodObject<{
                            logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                            comparisons: z.ZodArray<z.ZodObject<{
                                id: z.ZodString;
                                variableId: z.ZodOptional<z.ZodString>;
                                comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                                value: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }, {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        }, {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    }, {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    }>>;
                }>, "strip", z.ZodTypeAny, {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }, {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }>, "many">;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    isMultipleChoice: z.ZodBoolean;
                    buttonLabel: z.ZodString;
                    dynamicVariableId: z.ZodOptional<z.ZodString>;
                    isSearchable: z.ZodOptional<z.ZodBoolean>;
                    searchInputPlaceholder: z.ZodOptional<z.ZodString>;
                }>, "strip", z.ZodTypeAny, {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                }, {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                };
                type: import("./blocks").InputBlockType.CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                };
                type: import("./blocks").InputBlockType.CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.EMAIL]>;
                options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                    }, {
                        button: string;
                        placeholder: string;
                    }>;
                }>, {
                    retryMessageContent: z.ZodString;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.EMAIL;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.EMAIL;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.NUMBER]>;
                options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                    }, {
                        button: string;
                        placeholder: string;
                    }>;
                }>, {
                    min: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                    max: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                    step: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                };
                type: import("./blocks").InputBlockType.NUMBER;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                };
                type: import("./blocks").InputBlockType.NUMBER;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.URL]>;
                options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                    }, {
                        button: string;
                        placeholder: string;
                    }>;
                }>, {
                    retryMessageContent: z.ZodString;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.URL;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.URL;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.PHONE]>;
                options: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                    }, {
                        button: string;
                        placeholder: string;
                    }>;
                }>, {
                    retryMessageContent: z.ZodString;
                    defaultCountryCode: z.ZodOptional<z.ZodString>;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PHONE;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PHONE;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.DATE]>;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    labels: z.ZodObject<{
                        button: z.ZodString;
                        from: z.ZodString;
                        to: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        from: string;
                        to: string;
                    }, {
                        button: string;
                        from: string;
                        to: string;
                    }>;
                    hasTime: z.ZodBoolean;
                    isRange: z.ZodBoolean;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.DATE;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.DATE;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.PAYMENT]>;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    provider: z.ZodNativeEnum<typeof import("./blocks").PaymentProvider>;
                    labels: z.ZodObject<{
                        button: z.ZodString;
                        success: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        success?: string | undefined;
                    }, {
                        button: string;
                        success?: string | undefined;
                    }>;
                    additionalInformation: z.ZodOptional<z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        name: z.ZodOptional<z.ZodString>;
                        email: z.ZodOptional<z.ZodString>;
                        phoneNumber: z.ZodOptional<z.ZodString>;
                        address: z.ZodOptional<z.ZodObject<{
                            country: z.ZodOptional<z.ZodString>;
                            line1: z.ZodOptional<z.ZodString>;
                            line2: z.ZodOptional<z.ZodString>;
                            state: z.ZodOptional<z.ZodString>;
                            city: z.ZodOptional<z.ZodString>;
                            postalCode: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        }, {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    }, {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    }>>;
                    credentialsId: z.ZodOptional<z.ZodString>;
                    currency: z.ZodString;
                    amount: z.ZodOptional<z.ZodString>;
                    retryMessageContent: z.ZodOptional<z.ZodString>;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                }, {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PAYMENT;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PAYMENT;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./blocks").InputBlockType.RATING>;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    buttonType: z.ZodUnion<[z.ZodLiteral<"Icons">, z.ZodLiteral<"Numbers">]>;
                    length: z.ZodNumber;
                    labels: z.ZodObject<{
                        left: z.ZodOptional<z.ZodString>;
                        right: z.ZodOptional<z.ZodString>;
                        button: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    }, {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    }>;
                    customIcon: z.ZodObject<{
                        isEnabled: z.ZodBoolean;
                        svg: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    }, {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    }>;
                    isOneClickSubmitEnabled: z.ZodOptional<z.ZodBoolean>;
                }>, "strip", z.ZodTypeAny, {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                }, {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                };
                type: import("./blocks").InputBlockType.RATING;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                };
                type: import("./blocks").InputBlockType.RATING;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodLiteral<import("./blocks").InputBlockType.FILE>;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    isRequired: z.ZodOptional<z.ZodBoolean>;
                    isMultipleAllowed: z.ZodBoolean;
                    labels: z.ZodObject<{
                        placeholder: z.ZodString;
                        button: z.ZodString;
                        clear: z.ZodOptional<z.ZodString>;
                        skip: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    }, {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    }>;
                    sizeLimit: z.ZodOptional<z.ZodNumber>;
                }>, "strip", z.ZodTypeAny, {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                }, {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                };
                type: import("./blocks").InputBlockType.FILE;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                };
                type: import("./blocks").InputBlockType.FILE;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").InputBlockType.PICTURE_CHOICE]>;
                items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                    id: z.ZodString;
                    blockId: z.ZodString;
                    outgoingEdgeId: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<import("./items").ItemType.PICTURE_CHOICE>;
                    pictureSrc: z.ZodOptional<z.ZodString>;
                    title: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    displayCondition: z.ZodOptional<z.ZodObject<{
                        isEnabled: z.ZodOptional<z.ZodBoolean>;
                        condition: z.ZodOptional<z.ZodObject<{
                            logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                            comparisons: z.ZodArray<z.ZodObject<{
                                id: z.ZodString;
                                variableId: z.ZodOptional<z.ZodString>;
                                comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                                value: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }, {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        }, {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    }, {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    }>>;
                }>, "strip", z.ZodTypeAny, {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }, {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }>, "many">;
                options: z.ZodObject<z.objectUtil.extendShape<{
                    variableId: z.ZodOptional<z.ZodString>;
                }, {
                    isMultipleChoice: z.ZodOptional<z.ZodBoolean>;
                    isSearchable: z.ZodOptional<z.ZodBoolean>;
                    buttonLabel: z.ZodString;
                    searchInputPlaceholder: z.ZodString;
                    dynamicItems: z.ZodOptional<z.ZodObject<{
                        isEnabled: z.ZodOptional<z.ZodBoolean>;
                        titlesVariableId: z.ZodOptional<z.ZodString>;
                        descriptionsVariableId: z.ZodOptional<z.ZodString>;
                        pictureSrcsVariableId: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    }, {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    }>>;
                }>, "strip", z.ZodTypeAny, {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                }, {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                };
                type: import("./blocks").InputBlockType.PICTURE_CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                };
                type: import("./blocks").InputBlockType.PICTURE_CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.SCRIPT]>;
                options: z.ZodObject<{
                    name: z.ZodString;
                    content: z.ZodOptional<z.ZodString>;
                    shouldExecuteInParentContext: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                }, {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SCRIPT;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SCRIPT;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.CONDITION]>;
                items: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
                    id: z.ZodString;
                    blockId: z.ZodString;
                    outgoingEdgeId: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<import("./items").ItemType.CONDITION>;
                    content: z.ZodObject<{
                        logicalOperator: z.ZodNativeEnum<typeof import("./blocks").LogicalOperator>;
                        comparisons: z.ZodArray<z.ZodObject<{
                            id: z.ZodString;
                            variableId: z.ZodOptional<z.ZodString>;
                            comparisonOperator: z.ZodOptional<z.ZodNativeEnum<typeof import("./blocks").ComparisonOperators>>;
                            value: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }, {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }, {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    }>;
                }>, "strip", z.ZodTypeAny, {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }>, "many">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                type: import("./blocks").LogicBlockType.CONDITION;
                items: {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                type: import("./blocks").LogicBlockType.CONDITION;
                items: {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.REDIRECT]>;
                options: z.ZodObject<{
                    url: z.ZodOptional<z.ZodString>;
                    isNewTab: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    isNewTab: boolean;
                    url?: string | undefined;
                }, {
                    isNewTab: boolean;
                    url?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    isNewTab: boolean;
                    url?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.REDIRECT;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    isNewTab: boolean;
                    url?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.REDIRECT;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.SET_VARIABLE]>;
                options: z.ZodObject<{
                    variableId: z.ZodOptional<z.ZodString>;
                    expressionToEvaluate: z.ZodOptional<z.ZodString>;
                    isCode: z.ZodOptional<z.ZodBoolean>;
                    type: z.ZodOptional<z.ZodEnum<["Custom", "Empty", "User ID", "Today", "Yesterday", "Tomorrow", "Random ID", "Moment of the day", "Map item with same index"]>>;
                    mapListItemParams: z.ZodOptional<z.ZodObject<{
                        baseItemVariableId: z.ZodOptional<z.ZodString>;
                        baseListVariableId: z.ZodOptional<z.ZodString>;
                        targetListVariableId: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    }, {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    }>>;
                    isExecutedOnClient: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                }, {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SET_VARIABLE;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SET_VARIABLE;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.AGENT_LINK]>;
                options: z.ZodObject<{
                    agentId: z.ZodOptional<z.ZodString>;
                    groupId: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                }, {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.AGENT_LINK;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.AGENT_LINK;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.WAIT]>;
                options: z.ZodObject<{
                    secondsToWaitFor: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    secondsToWaitFor?: string | undefined;
                }, {
                    secondsToWaitFor?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    secondsToWaitFor?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.WAIT;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    secondsToWaitFor?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.WAIT;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.JUMP]>;
                options: z.ZodObject<{
                    groupId: z.ZodOptional<z.ZodString>;
                    blockId: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                }, {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.JUMP;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.JUMP;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").LogicBlockType.AB_TEST]>;
                items: z.ZodTuple<[z.ZodObject<z.objectUtil.extendShape<{
                    id: z.ZodString;
                    blockId: z.ZodString;
                    outgoingEdgeId: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<import("./items").ItemType.AB_TEST>;
                    path: z.ZodLiteral<"a">;
                }>, "strip", z.ZodTypeAny, {
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<{
                    id: z.ZodString;
                    blockId: z.ZodString;
                    outgoingEdgeId: z.ZodOptional<z.ZodString>;
                }, {
                    type: z.ZodLiteral<import("./items").ItemType.AB_TEST>;
                    path: z.ZodLiteral<"b">;
                }>, "strip", z.ZodTypeAny, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }>], null>;
                options: z.ZodObject<{
                    aPercent: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    aPercent: number;
                }, {
                    aPercent: number;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    aPercent: number;
                };
                type: import("./blocks").LogicBlockType.AB_TEST;
                items: [{
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }];
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    aPercent: number;
                };
                type: import("./blocks").LogicBlockType.AB_TEST;
                items: [{
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }];
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS]>;
                options: z.ZodObject<{
                    trackingId: z.ZodOptional<z.ZodString>;
                    category: z.ZodOptional<z.ZodString>;
                    action: z.ZodOptional<z.ZodString>;
                    label: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodType<`{{${string}}}`, z.ZodTypeDef, `{{${string}}}`>]>>;
                    sendTo: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                }, {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                }>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                };
                type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                };
                type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
                outgoingEdgeId?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<{
                id: z.ZodString;
                groupId: z.ZodString;
                outgoingEdgeId: z.ZodOptional<z.ZodString>;
            }, {
                type: z.ZodEnum<[import("./blocks").IntegrationBlockType.PIXEL]>;
                options: z.ZodDiscriminatedUnion<"eventType", [z.ZodObject<z.objectUtil.extendShape<{
                    pixelId: z.ZodOptional<z.ZodString>;
                    isInitSkip: z.ZodOptional<z.ZodBoolean>;
                    params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        key: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                    }, "strip", z.ZodTypeAny, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }>, "many">>;
                }, {
                    eventType: z.ZodUndefined;
                }>, "strip", z.ZodTypeAny, {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                }, {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<{
                    pixelId: z.ZodOptional<z.ZodString>;
                    isInitSkip: z.ZodOptional<z.ZodBoolean>;
                    params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        key: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                    }, "strip", z.ZodTypeAny, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }>, "many">>;
                }, {
                    eventType: z.ZodEnum<["Lead", "Contact", "CompleteRegistration", "Schedule", "SubmitApplication", "ViewContent", "AddPaymentInfo", "AddToCart", "AddToWishlist", "CustomizeProduct", "Donate", "FindLocation", "InitiateCheckout", "Purchase", "Search", "StartTrial", "Subscribe"]>;
                }>, "strip", z.ZodTypeAny, {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                }, {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<{
                    pixelId: z.ZodOptional<z.ZodString>;
                    isInitSkip: z.ZodOptional<z.ZodBoolean>;
                    params: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        key: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                    }, "strip", z.ZodTypeAny, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }, {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }>, "many">>;
                }, {
                    eventType: z.ZodEnum<["Custom"]>;
                    name: z.ZodOptional<z.ZodString>;
                }>, "strip", z.ZodTypeAny, {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                }, {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                }>]>;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                groupId: string;
                options: {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                } | {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                } | {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                };
                type: import("./blocks").IntegrationBlockType.PIXEL;
                outgoingEdgeId?: string | undefined;
            }, {
                id: string;
                groupId: string;
                options: {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                } | {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                } | {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                };
                type: import("./blocks").IntegrationBlockType.PIXEL;
                outgoingEdgeId?: string | undefined;
            }>]>, "many">;
        }, "strip", z.ZodTypeAny, {
            title: string;
            id: string;
            graphCoordinates: {
                x: number;
                y: number;
            };
            blocks: ({
                id: string;
                groupId: string;
                type: BubbleBlockType.AUDIO;
                content: {
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.EMBED;
                content: {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.IMAGE;
                content: {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.TEXT;
                content: {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.VIDEO;
                content: {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: import("./blocks").LogicBlockType.CONDITION;
                items: {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                };
                type: import("./blocks").InputBlockType.CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.DATE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.TEXT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.EMAIL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                };
                type: import("./blocks").InputBlockType.FILE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                };
                type: import("./blocks").InputBlockType.NUMBER;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PAYMENT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PHONE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                };
                type: import("./blocks").InputBlockType.RATING;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.URL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                };
                type: import("./blocks").InputBlockType.PICTURE_CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                };
                type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                } | {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                } | {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                };
                type: import("./blocks").IntegrationBlockType.PIXEL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SCRIPT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    isNewTab: boolean;
                    url?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.REDIRECT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SET_VARIABLE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.AGENT_LINK;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    secondsToWaitFor?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.WAIT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    aPercent: number;
                };
                type: import("./blocks").LogicBlockType.AB_TEST;
                items: [{
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }];
                outgoingEdgeId?: string | undefined;
            } | {
                label: string;
                id: string;
                groupId: string;
                type: "start";
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.JUMP;
                outgoingEdgeId?: string | undefined;
            })[];
        }, {
            title: string;
            id: string;
            graphCoordinates: {
                x: number;
                y: number;
            };
            blocks: ({
                id: string;
                groupId: string;
                type: BubbleBlockType.AUDIO;
                content: {
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.EMBED;
                content: {
                    height: number | `{{${string}}}`;
                    url?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.IMAGE;
                content: {
                    url?: string | undefined;
                    clickLink?: {
                        url?: string | undefined;
                        alt?: string | undefined;
                    } | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.TEXT;
                content: {
                    richText: any[];
                    html?: string | undefined;
                    plainText?: string | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: BubbleBlockType.VIDEO;
                content: {
                    url?: string | undefined;
                    id?: string | undefined;
                    type?: import("./blocks").VideoBubbleContentType | undefined;
                };
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                type: import("./blocks").LogicBlockType.CONDITION;
                items: {
                    id: string;
                    type: import("./items").ItemType.CONDITION;
                    content: {
                        logicalOperator: import("./blocks").LogicalOperator;
                        comparisons: {
                            id: string;
                            value?: string | undefined;
                            variableId?: string | undefined;
                            comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                        }[];
                    };
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    isMultipleChoice: boolean;
                    buttonLabel: string;
                    variableId?: string | undefined;
                    dynamicVariableId?: string | undefined;
                    isSearchable?: boolean | undefined;
                    searchInputPlaceholder?: string | undefined;
                };
                type: import("./blocks").InputBlockType.CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.BUTTON;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                    content?: string | undefined;
                    isUrl?: boolean | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        from: string;
                        to: string;
                    };
                    hasTime: boolean;
                    isRange: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.DATE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    isLong: boolean;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.TEXT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.EMAIL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                        clear?: string | undefined;
                        skip?: string | undefined;
                    };
                    isMultipleAllowed: boolean;
                    variableId?: string | undefined;
                    isRequired?: boolean | undefined;
                    sizeLimit?: number | undefined;
                };
                type: import("./blocks").InputBlockType.FILE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    variableId?: string | undefined;
                    min?: number | `{{${string}}}` | undefined;
                    max?: number | `{{${string}}}` | undefined;
                    step?: number | `{{${string}}}` | undefined;
                };
                type: import("./blocks").InputBlockType.NUMBER;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        success?: string | undefined;
                    };
                    provider: import("./blocks").PaymentProvider;
                    currency: string;
                    variableId?: string | undefined;
                    retryMessageContent?: string | undefined;
                    additionalInformation?: {
                        address?: {
                            country?: string | undefined;
                            line1?: string | undefined;
                            line2?: string | undefined;
                            state?: string | undefined;
                            city?: string | undefined;
                            postalCode?: string | undefined;
                        } | undefined;
                        description?: string | undefined;
                        name?: string | undefined;
                        email?: string | undefined;
                        phoneNumber?: string | undefined;
                    } | undefined;
                    credentialsId?: string | undefined;
                    amount?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PAYMENT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                    defaultCountryCode?: string | undefined;
                };
                type: import("./blocks").InputBlockType.PHONE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    length: number;
                    labels: {
                        button: string;
                        left?: string | undefined;
                        right?: string | undefined;
                    };
                    buttonType: "Icons" | "Numbers";
                    customIcon: {
                        isEnabled: boolean;
                        svg?: string | undefined;
                    };
                    variableId?: string | undefined;
                    isOneClickSubmitEnabled?: boolean | undefined;
                };
                type: import("./blocks").InputBlockType.RATING;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    labels: {
                        button: string;
                        placeholder: string;
                    };
                    retryMessageContent: string;
                    variableId?: string | undefined;
                };
                type: import("./blocks").InputBlockType.URL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    buttonLabel: string;
                    searchInputPlaceholder: string;
                    variableId?: string | undefined;
                    isMultipleChoice?: boolean | undefined;
                    isSearchable?: boolean | undefined;
                    dynamicItems?: {
                        isEnabled?: boolean | undefined;
                        titlesVariableId?: string | undefined;
                        descriptionsVariableId?: string | undefined;
                        pictureSrcsVariableId?: string | undefined;
                    } | undefined;
                };
                type: import("./blocks").InputBlockType.PICTURE_CHOICE;
                items: {
                    id: string;
                    type: import("./items").ItemType.PICTURE_CHOICE;
                    blockId: string;
                    title?: string | undefined;
                    outgoingEdgeId?: string | undefined;
                    displayCondition?: {
                        isEnabled?: boolean | undefined;
                        condition?: {
                            logicalOperator: import("./blocks").LogicalOperator;
                            comparisons: {
                                id: string;
                                value?: string | undefined;
                                variableId?: string | undefined;
                                comparisonOperator?: import("./blocks").ComparisonOperators | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    description?: string | undefined;
                    pictureSrc?: string | undefined;
                }[];
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    value?: number | `{{${string}}}` | undefined;
                    label?: string | undefined;
                    trackingId?: string | undefined;
                    category?: string | undefined;
                    action?: string | undefined;
                    sendTo?: string | undefined;
                };
                type: import("./blocks").IntegrationBlockType.GOOGLE_ANALYTICS;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                    eventType?: undefined;
                } | {
                    eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                } | {
                    eventType: "Custom";
                    params?: {
                        id: string;
                        value?: any;
                        key?: string | undefined;
                    }[] | undefined;
                    name?: string | undefined;
                    pixelId?: string | undefined;
                    isInitSkip?: boolean | undefined;
                };
                type: import("./blocks").IntegrationBlockType.PIXEL;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    name: string;
                    content?: string | undefined;
                    shouldExecuteInParentContext?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SCRIPT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    isNewTab: boolean;
                    url?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.REDIRECT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    type?: "Custom" | "Empty" | "User ID" | "Today" | "Yesterday" | "Tomorrow" | "Random ID" | "Moment of the day" | "Map item with same index" | undefined;
                    variableId?: string | undefined;
                    expressionToEvaluate?: string | undefined;
                    isCode?: boolean | undefined;
                    mapListItemParams?: {
                        baseItemVariableId?: string | undefined;
                        baseListVariableId?: string | undefined;
                        targetListVariableId?: string | undefined;
                    } | undefined;
                    isExecutedOnClient?: boolean | undefined;
                };
                type: import("./blocks").LogicBlockType.SET_VARIABLE;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    agentId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.AGENT_LINK;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    secondsToWaitFor?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.WAIT;
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    aPercent: number;
                };
                type: import("./blocks").LogicBlockType.AB_TEST;
                items: [{
                    path: "a";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }, {
                    path: "b";
                    id: string;
                    type: import("./items").ItemType.AB_TEST;
                    blockId: string;
                    outgoingEdgeId?: string | undefined;
                }];
                outgoingEdgeId?: string | undefined;
            } | {
                label: string;
                id: string;
                groupId: string;
                type: "start";
                outgoingEdgeId?: string | undefined;
            } | {
                id: string;
                groupId: string;
                options: {
                    groupId?: string | undefined;
                    blockId?: string | undefined;
                };
                type: import("./blocks").LogicBlockType.JUMP;
                outgoingEdgeId?: string | undefined;
            })[];
        }>, "many">;
        edges: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            from: z.ZodObject<{
                groupId: z.ZodString;
                blockId: z.ZodString;
                itemId: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                groupId: string;
                blockId: string;
                itemId?: string | undefined;
            }, {
                groupId: string;
                blockId: string;
                itemId?: string | undefined;
            }>;
            to: z.ZodObject<{
                groupId: z.ZodString;
                blockId: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                groupId: string;
                blockId?: string | undefined;
            }, {
                groupId: string;
                blockId?: string | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            id: string;
            from: {
                groupId: string;
                blockId: string;
                itemId?: string | undefined;
            };
            to: {
                groupId: string;
                blockId?: string | undefined;
            };
        }, {
            id: string;
            from: {
                groupId: string;
                blockId: string;
                itemId?: string | undefined;
            };
            to: {
                groupId: string;
                blockId?: string | undefined;
            };
        }>, "many">;
        variables: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            value: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodNullable<z.ZodString>, "many">]>>>;
        }, "strip", z.ZodTypeAny, {
            id: string;
            name: string;
            value?: string | (string | null)[] | null | undefined;
        }, {
            id: string;
            name: string;
            value?: string | (string | null)[] | null | undefined;
        }>, "many">;
        theme: z.ZodObject<{
            general: z.ZodObject<{
                font: z.ZodString;
                background: z.ZodObject<{
                    type: z.ZodNativeEnum<typeof import("./agent").BackgroundType>;
                    content: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                }, {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            }, {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            }>;
            chat: z.ZodObject<{
                hostAvatar: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodBoolean;
                    url: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled: boolean;
                    url?: string | undefined;
                }, {
                    isEnabled: boolean;
                    url?: string | undefined;
                }>>;
                guestAvatar: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodBoolean;
                    url: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled: boolean;
                    url?: string | undefined;
                }, {
                    isEnabled: boolean;
                    url?: string | undefined;
                }>>;
                hostBubbles: z.ZodObject<{
                    backgroundColor: z.ZodString;
                    color: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    color: string;
                    backgroundColor: string;
                }, {
                    color: string;
                    backgroundColor: string;
                }>;
                guestBubbles: z.ZodObject<{
                    backgroundColor: z.ZodString;
                    color: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    color: string;
                    backgroundColor: string;
                }, {
                    color: string;
                    backgroundColor: string;
                }>;
                buttons: z.ZodObject<{
                    backgroundColor: z.ZodString;
                    color: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    color: string;
                    backgroundColor: string;
                }, {
                    color: string;
                    backgroundColor: string;
                }>;
                inputs: z.ZodObject<z.objectUtil.extendShape<{
                    backgroundColor: z.ZodString;
                    color: z.ZodString;
                }, {
                    placeholderColor: z.ZodString;
                }>, "strip", z.ZodTypeAny, {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                }, {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                }>;
                roundness: z.ZodOptional<z.ZodEnum<["none", "medium", "large"]>>;
            }, "strip", z.ZodTypeAny, {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            }, {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            }>;
            customCss: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        }, {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        }>;
        selectedThemeTemplateId: z.ZodNullable<z.ZodString>;
        settings: z.ZodObject<{
            general: z.ZodObject<{
                isBrandingEnabled: z.ZodBoolean;
                isTypingEmulationEnabled: z.ZodOptional<z.ZodBoolean>;
                isInputPrefillEnabled: z.ZodOptional<z.ZodBoolean>;
                isHideQueryParamsEnabled: z.ZodOptional<z.ZodBoolean>;
                isNewResultOnRefreshEnabled: z.ZodOptional<z.ZodBoolean>;
                rememberUser: z.ZodOptional<z.ZodObject<{
                    isEnabled: z.ZodOptional<z.ZodBoolean>;
                    storage: z.ZodOptional<z.ZodEnum<["session", "local"]>>;
                }, "strip", z.ZodTypeAny, {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                }, {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            }, {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            }>;
            typingEmulation: z.ZodObject<{
                enabled: z.ZodBoolean;
                speed: z.ZodNumber;
                maxDelay: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            }, {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            }>;
            metadata: z.ZodObject<{
                title: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                imageUrl: z.ZodOptional<z.ZodString>;
                favIconUrl: z.ZodOptional<z.ZodString>;
                customHeadCode: z.ZodOptional<z.ZodString>;
                googleTagManagerId: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            }, {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        }, {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        }>;
        createdAt: z.ZodDate;
        updatedAt: z.ZodDate;
        icon: z.ZodNullable<z.ZodString>;
        folderId: z.ZodNullable<z.ZodString>;
        publicId: z.ZodNullable<z.ZodString>;
        customDomain: z.ZodNullable<z.ZodString>;
        workspaceId: z.ZodString;
        resultsTablePreferences: z.ZodNullable<z.ZodObject<{
            columnsOrder: z.ZodArray<z.ZodString, "many">;
            columnsVisibility: z.ZodRecord<z.ZodString, z.ZodBoolean>;
            columnsWidth: z.ZodRecord<z.ZodString, z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            columnsOrder: string[];
            columnsVisibility: Record<string, boolean>;
            columnsWidth: Record<string, number>;
        }, {
            columnsOrder: string[];
            columnsVisibility: Record<string, boolean>;
            columnsWidth: Record<string, number>;
        }>>;
        isArchived: z.ZodBoolean;
        isClosed: z.ZodBoolean;
    }, "id" | "theme" | "settings">, "strip", z.ZodTypeAny, {
        id: string;
        theme: {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        };
        settings: {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        };
    }, {
        id: string;
        theme: {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        };
        settings: {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        };
    }>>;
    resultId: z.ZodOptional<z.ZodString>;
    dynamicTheme: z.ZodOptional<z.ZodObject<{
        hostAvatarUrl: z.ZodOptional<z.ZodString>;
        guestAvatarUrl: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        hostAvatarUrl?: string | undefined;
        guestAvatarUrl?: string | undefined;
    }, {
        hostAvatarUrl?: string | undefined;
        guestAvatarUrl?: string | undefined;
    }>>;
    logs: z.ZodOptional<z.ZodArray<z.ZodObject<z.objectUtil.extendShape<Pick<{
        id: z.ZodString;
        createdAt: z.ZodDate;
        resultId: z.ZodString;
        status: z.ZodString;
        description: z.ZodString;
        details: z.ZodNullable<z.ZodString>;
    }, "status" | "description">, {
        details: z.ZodOptional<z.ZodUnknown>;
    }>, "strip", z.ZodTypeAny, {
        status: string;
        description: string;
        details?: unknown;
    }, {
        status: string;
        description: string;
        details?: unknown;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    sessionId?: string | undefined;
    input?: any;
    resultId?: string | undefined;
    messages?: any;
    clientSideActions?: ({
        lastBubbleBlockId?: string | undefined;
    } & ({
        scriptToExecute: {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        };
    } | {
        redirect: {
            isNewTab: boolean;
            url?: string | undefined;
        };
    } | {
        chatwoot: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    } | {
        googleAnalytics: {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        };
    } | {
        wait: {
            secondsToWaitFor: number;
        };
    } | {
        setVariable: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    } | {
        streamOpenAiChatCompletion: {
            message?: string | undefined;
        };
    } | {
        startPropsToInject: {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        };
    } | {
        pixel: {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        } | {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        } | {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        };
    }))[] | undefined;
    agentConfig?: {
        id: string;
        theme: {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        };
        settings: {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        };
    } | undefined;
    dynamicTheme?: {
        hostAvatarUrl?: string | undefined;
        guestAvatarUrl?: string | undefined;
    } | undefined;
    logs?: {
        status: string;
        description: string;
        details?: unknown;
    }[] | undefined;
}, {
    sessionId?: string | undefined;
    input?: any;
    resultId?: string | undefined;
    messages?: any;
    clientSideActions?: ({
        lastBubbleBlockId?: string | undefined;
    } & ({
        scriptToExecute: {
            content: string;
            args: {
                id: string;
                value?: string | number | boolean | (string | null)[] | null | undefined;
            }[];
        };
    } | {
        redirect: {
            isNewTab: boolean;
            url?: string | undefined;
        };
    } | {
        chatwoot: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    } | {
        googleAnalytics: {
            value?: number | `{{${string}}}` | undefined;
            label?: string | undefined;
            trackingId?: string | undefined;
            category?: string | undefined;
            action?: string | undefined;
            sendTo?: string | undefined;
        };
    } | {
        wait: {
            secondsToWaitFor: number;
        };
    } | {
        setVariable: {
            scriptToExecute: {
                content: string;
                args: {
                    id: string;
                    value?: string | number | boolean | (string | null)[] | null | undefined;
                }[];
            };
        };
    } | {
        streamOpenAiChatCompletion: {
            message?: string | undefined;
        };
    } | {
        startPropsToInject: {
            pixelId?: string | undefined;
            customHeadCode?: string | undefined;
            googleAnalyticsId?: string | undefined;
            gtmId?: string | undefined;
        };
    } | {
        pixel: {
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
            eventType?: undefined;
        } | {
            eventType: "Lead" | "Contact" | "CompleteRegistration" | "Schedule" | "SubmitApplication" | "ViewContent" | "AddPaymentInfo" | "AddToCart" | "AddToWishlist" | "CustomizeProduct" | "Donate" | "FindLocation" | "InitiateCheckout" | "Purchase" | "Search" | "StartTrial" | "Subscribe";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        } | {
            eventType: "Custom";
            params?: {
                id: string;
                value?: any;
                key?: string | undefined;
            }[] | undefined;
            name?: string | undefined;
            pixelId?: string | undefined;
            isInitSkip?: boolean | undefined;
        };
    }))[] | undefined;
    agentConfig?: {
        id: string;
        theme: {
            general: {
                font: string;
                background: {
                    type: import("./agent").BackgroundType;
                    content?: string | undefined;
                };
            };
            chat: {
                hostBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                guestBubbles: {
                    color: string;
                    backgroundColor: string;
                };
                buttons: {
                    color: string;
                    backgroundColor: string;
                };
                inputs: {
                    color: string;
                    backgroundColor: string;
                    placeholderColor: string;
                };
                hostAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                guestAvatar?: {
                    isEnabled: boolean;
                    url?: string | undefined;
                } | undefined;
                roundness?: "medium" | "large" | "none" | undefined;
            };
            customCss?: string | undefined;
        };
        settings: {
            general: {
                isBrandingEnabled: boolean;
                isTypingEmulationEnabled?: boolean | undefined;
                isInputPrefillEnabled?: boolean | undefined;
                isHideQueryParamsEnabled?: boolean | undefined;
                isNewResultOnRefreshEnabled?: boolean | undefined;
                rememberUser?: {
                    isEnabled?: boolean | undefined;
                    storage?: "session" | "local" | undefined;
                } | undefined;
            };
            typingEmulation: {
                enabled: boolean;
                speed: number;
                maxDelay: number;
            };
            metadata: {
                title?: string | undefined;
                description?: string | undefined;
                imageUrl?: string | undefined;
                favIconUrl?: string | undefined;
                customHeadCode?: string | undefined;
                googleTagManagerId?: string | undefined;
            };
        };
    } | undefined;
    dynamicTheme?: {
        hostAvatarUrl?: string | undefined;
        guestAvatarUrl?: string | undefined;
    } | undefined;
    logs?: {
        status: string;
        description: string;
        details?: unknown;
    }[] | undefined;
}>;
export type ChatReply = z.infer<typeof chatReplySchema>;
export type ChatMessage = z.infer<typeof chatMessageSchema>;
export type SendMessageInput = z.infer<typeof sendMessageInputSchema>;
export type ScriptToExecute = z.infer<typeof scriptToExecuteSchema>;
export type StartParams = z.infer<typeof startParamsSchema>;
export type RuntimeOptions = z.infer<typeof runtimeOptionsSchema>;
export type StartAgent = z.infer<typeof startAgentSchema>;
export type ReplyLog = z.infer<typeof replyLogSchema>;
export type StartPropsToInject = z.infer<typeof startPropsToInjectSchema>;
export {};
//# sourceMappingURL=chat.d.ts.map